@@ -14,7 +14,7 @@ class RequestsResponse(Response):
 
     @property
     def text(self) -> str:
-        return self.content.decode(self.encoding)
+        return self.content.decode(self.encoding) if self.content is not None else ''
 
     @property
     def content(self) -> bytes:
